@@ -380,9 +380,10 @@ def _send_offer_assignment_email_via_braze(self, user_email, offer_assignment_id
     """
     config = get_braze_configuration(site_code)
     try:
+        user_emails = [user_email]
         braze_client = get_braze_client(site_code)
         response = braze_client.send_message(
-            email_ids=list(user_email),
+            email_ids=user_emails,
             subject=subject,
             body=email_body,
             sender_alias=sender_alias
@@ -484,7 +485,14 @@ def send_offer_assignment_email(self, user_email, offer_assignment_id, subject,
             self, user_email, offer_assignment_id, subject, email_body, sender_alias, site_code, base_enterprise_url)
     else:
         _send_offer_assignment_email_via_sailthru(
-            self, user_email, offer_assignment_id, subject, email_body, sender_alias, site_code, base_enterprise_url)
+            self, user_email,
+            offer_assignment_id,
+            subject,
+            email_body,
+            sender_alias,
+            site_code=site_code,
+            base_enterprise_url=base_enterprise_url
+        )
 
 
 def _update_assignment_email_status(offer_assignment_id, send_id, status, site_code=None):
@@ -532,9 +540,10 @@ def _send_offer_update_email_via_braze(self, user_email, subject, email_body, se
     """
     config = get_braze_configuration(site_code)
     try:
+        user_emails = [user_email]
         braze_client = get_braze_client(site_code)
         braze_client.send_message(
-            email_ids=list(user_email),
+            email_ids=user_emails,
             subject=subject,
             body=email_body,
             sender_alias=sender_alias
@@ -549,7 +558,7 @@ def _send_offer_update_email_via_braze(self, user_email, subject, email_body, se
         )
 
 
-def _send_offer_update_email_via_sailthru(self, user_email, subject, email_body, sender_alias, site_code=None):
+def _send_offer_update_email_via_sailthru(self, user_email, subject, email_body, sender_alias, site_code=None, base_enterprise_url=''):
     """
     Sends the offer emails after assignment via sailthru, either for revoking or reminding.
 
@@ -569,6 +578,7 @@ def _send_offer_update_email_via_sailthru(self, user_email, subject, email_body,
             'subject': subject,
             'email_body': email_body,
             'sender_alias': sender_alias,
+            'base_enterprise_url': base_enterprise_url
         },
         logger_prefix='Offer Assignment',
         site_code=site_code,
@@ -580,7 +590,7 @@ def _send_offer_update_email_via_sailthru(self, user_email, subject, email_body,
 
 
 @shared_task(bind=True, ignore_result=True)
-def send_offer_update_email(self, user_email, subject, email_body, sender_alias, site_code=None):
+def send_offer_update_email(self, user_email, subject, email_body, sender_alias, site_code=None, base_enterprise_url=''):
     """
     Sends the offer emails after assignment, either for revoking or reminding.
 
@@ -591,13 +601,21 @@ def send_offer_update_email(self, user_email, subject, email_body, sender_alias,
         email_body (str): The body of the email.
         site_code (str): Identifier of the site sending the email.
         sender_alias (str): Enterprise Customer sender alias used as From Name.
+        base_enterprise_url (str): Enterprise learner portal url.
     """
     config = get_braze_configuration(site_code)
     braze_enable = config.get('BRAZE_ENABLE')
     if braze_enable:
         _send_offer_update_email_via_braze(self, user_email, subject, email_body, sender_alias, site_code)
     else:
-        _send_offer_update_email_via_sailthru(self, user_email, subject, email_body, sender_alias, site_code)
+        _send_offer_update_email_via_sailthru(self,
+            user_email,
+            subject,
+            email_body,
+            sender_alias,
+            site_code=site_code,
+            base_enterprise_url=base_enterprise_url
+        )
 
 
 def _send_offer_usage_email_via_braze(self, emails, subject, email_body, site_code=None):
@@ -613,9 +631,10 @@ def _send_offer_usage_email_via_braze(self, emails, subject, email_body, site_co
     """
     config = get_braze_configuration(site_code)
     try:
+        user_emails = list(emails.strip().split(","))
         braze_client = get_braze_client(site_code)
         braze_client.send_message(
-            email_ids=list(emails),
+            email_ids=user_emails,
             subject=subject,
             body=email_body
         )
@@ -629,7 +648,7 @@ def _send_offer_usage_email_via_braze(self, emails, subject, email_body, site_co
         )
 
 
-def _send_offer_usage_email_via_sailthru(self, emails, subject, email_body, site_code=None):
+def _send_offer_usage_email_via_sailthru(self, emails, subject, email_body, site_code=None, base_enterprise_url=''):
     """
     Sends the offer usage email via sailthru.
 
@@ -639,6 +658,7 @@ def _send_offer_usage_email_via_sailthru(self, emails, subject, email_body, site
         subject (str): Email subject.
         email_body (str): The body of the email.
         site_code (str): Identifier of the site sending the email.
+        base_enterprise_url (str): Url for the enterprise's learner portal
     """
     config = get_sailthru_configuration(site_code)
     notification = Notification(
@@ -646,11 +666,12 @@ def _send_offer_usage_email_via_sailthru(self, emails, subject, email_body, site
         emails=emails,
         email_vars={
             'subject': subject,
-            'email_body': email_body
+            'email_body': email_body,
+            'base_enteprise_url': base_enterprise_url
         },
         logger_prefix='Offer Usage',
         site_code=site_code,
-        template='assignment_email'
+        template='assignment_email',
     )
     _, is_eligible_for_retry = notification.send(is_multi_send=True)
     if is_eligible_for_retry:
@@ -658,7 +679,7 @@ def _send_offer_usage_email_via_sailthru(self, emails, subject, email_body, site
 
 
 @shared_task(bind=True, ignore_result=True)
-def send_offer_usage_email(self, emails, subject, email_body, site_code=None):
+def send_offer_usage_email(self, emails, subject, email_body, site_code=None, base_enterprise_url=''):
     """
     Sends the offer usage email.
 
@@ -668,13 +689,21 @@ def send_offer_usage_email(self, emails, subject, email_body, site_code=None):
         subject (str): Email subject.
         email_body (str): The body of the email.
         site_code (str): Identifier of the site sending the email.
+        base_enterprise_url (str): Url of the enterprise's learner portal
     """
     config = get_braze_configuration(site_code)
     braze_enable = config.get('BRAZE_ENABLE')
     if braze_enable:
         _send_offer_usage_email_via_braze(self, emails, subject, email_body, site_code)
     else:
-        _send_offer_usage_email_via_sailthru(self, emails, subject, email_body, site_code)
+        _send_offer_usage_email_via_sailthru(
+            self,
+            emails,
+            subject,
+            email_body,
+            site_code=site_code,
+            base_enterprise_url=base_enterprise_url
+        )
 
 
 def _send_code_assignment_nudge_email_via_braze(self, email, subject, email_body, sender_alias, site_code=None):
@@ -691,9 +720,10 @@ def _send_code_assignment_nudge_email_via_braze(self, email, subject, email_body
     """
     config = get_braze_configuration(site_code)
     try:
+        user_emails = [email]
         braze_client = get_braze_client(site_code)
         braze_client.send_message(
-            email_ids=list(email),
+            email_ids=user_emails,
             subject=subject,
             body=email_body,
             sender_alias=sender_alias
@@ -708,7 +738,7 @@ def _send_code_assignment_nudge_email_via_braze(self, email, subject, email_body
         )
 
 
-def _send_code_assignment_nudge_email_via_sailthru(self, email, subject, email_body, sender_alias, site_code=None):
+def _send_code_assignment_nudge_email_via_sailthru(self, email, subject, email_body, sender_alias, site_code=None, base_enterprise_url=''):
     """
     Sends the code assignment nudge email via sailthru.
 
@@ -719,6 +749,7 @@ def _send_code_assignment_nudge_email_via_sailthru(self, email, subject, email_b
         email_body (str): The body of the email.
         sender_alias (str): Enterprise Customer sender alias used as From Name.
         site_code (str): Identifier of the site sending the email.
+        base_enterprise_url (str): Enterprise learner portal url
     """
     config = get_sailthru_configuration(site_code)
     notification = Notification(
@@ -728,6 +759,7 @@ def _send_code_assignment_nudge_email_via_sailthru(self, email, subject, email_b
             'subject': subject,
             'email_body': email_body,
             'sender_alias': sender_alias,
+            'base_enteprise_url': base_enterprise_url,
         },
         logger_prefix='Code Assignment Nudge Email',
         site_code=site_code,
@@ -739,7 +771,7 @@ def _send_code_assignment_nudge_email_via_sailthru(self, email, subject, email_b
 
 
 @shared_task(bind=True, ignore_result=True)
-def send_code_assignment_nudge_email(self, email, subject, email_body, sender_alias, site_code=None):
+def send_code_assignment_nudge_email(self, email, subject, email_body, sender_alias, site_code=None, base_enterprise_url=''):
     """
     Sends the code assignment nudge email.
 
@@ -750,10 +782,18 @@ def send_code_assignment_nudge_email(self, email, subject, email_body, sender_al
         email_body (str): The body of the email.
         sender_alias (str): Enterprise Customer sender alias used as From Name.
         site_code (str): Identifier of the site sending the email.
+        base_enterprise_url (str): Enterprise learner portal url.
     """
     config = get_braze_configuration(site_code)
     braze_enable = config.get('BRAZE_ENABLE')
     if braze_enable:
         _send_code_assignment_nudge_email_via_braze(self, email, subject, email_body, sender_alias, site_code)
     else:
-        _send_code_assignment_nudge_email_via_sailthru(self, email, subject, email_body, sender_alias, site_code)
+        _send_code_assignment_nudge_email_via_sailthru(self,
+            email,
+            subject,
+            email_body,
+            sender_alias,
+            site_code=site_code,
+            base_enterprise_url=base_enterprise_url
+        )
