@@ -713,12 +713,14 @@ class SendOfferEmailsTests(BaseSendEmailTests):
         'user_email': USER_EMAIL,
         'subject': SUBJECT,
         'email_body': EMAIL_BODY,
+        'base_enterprise_url': BASE_ENTERPRISE_URL,
         'sender_alias': SENDER_ALIAS,
     }
 
     USAGE_TASK_KWARGS = {
         'emails': EMAILS,
         'subject': SUBJECT,
+        'base_enterprise_url': BASE_ENTERPRISE_URL,
         'email_body': EMAIL_BODY,
     }
 
@@ -726,6 +728,7 @@ class SendOfferEmailsTests(BaseSendEmailTests):
         'email': USER_EMAIL,
         'subject': SUBJECT,
         'email_body': EMAIL_BODY,
+        'base_enterprise_url': BASE_ENTERPRISE_URL,
         'sender_alias': SENDER_ALIAS,
     }
 
@@ -1026,6 +1029,9 @@ class SendOfferEmailsTestsWithBraze(TestCase):
                 'EMAIL_BOUNCE_ENDPOINT': '/email/hard_bounces',
                 'NEW_ALIAS_ENDPOINT': '/users/alias/new',
                 'USERS_TRACK_ENDPOINT': '/users/track',
+                'EXPORT_ID_ENDPOINT': '/users/export/ids',
+                'CAMPAIGN_SEND_ENDPOINT': '/campaigns/trigger/send',
+                'ENTERPRISE_CAMPAIGN_ID': '',
                 'FROM_EMAIL': '<edx-for-business-no-reply@info.edx.org>',
                 'BRAZE_RETRY_SECONDS': 3600,
                 'BRAZE_RETRY_ATTEMPTS': 6,
@@ -1100,6 +1106,13 @@ class SendOfferEmailsTestsWithBraze(TestCase):
             json={'message': 'success'},
             status=201
         )
+        host = 'https://rest.iad-06.braze.com/users/export/ids'
+        responses.add(
+            responses.POST,
+            host,
+            json={"users": [], "message": "success"},
+            status=201
+        )
 
     @patch('ecommerce_worker.sailthru.v1.tasks.get_braze_client', Mock(side_effect=BrazeError))
     @ddt.data(
